@@ -3,8 +3,8 @@
 # Description: EquationSet macro
 # Detail: Presents multiple equations.
 
-# Remark 1.6.0
-# Copyright (c) 2009 - 2013 
+# Remark 1.6.4
+# Copyright (c) 2009 - 2014
 # Kalle Rutanen
 # Distributed under the MIT license (see license.txt).
 
@@ -30,10 +30,6 @@ class EquationSet_Macro(object):
 
         text = htmlDiv(text, className)
 
-        text.append('')
-        text.append('<div class = "remark-end-list"></div>')
-        text.append('')
-
         return text
 
     def outputType(self):
